.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "1.02",
.\"     date            = "18 May 1997",
.\"     time            = "12:47:00 MDT",
.\"     filename        = "bibsearch.man",
.\"     address         = "Center for Scientific Computing
.\"                        Department of Mathematics
.\"                        University of Utah
.\"                        Salt Lake City, UT 84112
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 581 4148",
.\"     checksum        = "07781 278 1022 7453",
.\"     email           = "beebe@math.utah.edu (Internet)",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "bibliography, BibTeX, searching",
.\"     supported       = "yes",
.\"     docstring       = "This file contains the UNIX manual pages
.\"                        for the bibsearch utility, an interface to
.\"                        a fast database search engine for searching
.\"                        BibTeX bibliography files.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.if t .ds Bi B\s-2IB\s+2T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Bi BibTeX
.if t .ds Te T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Te TeX
.TH BIBSEARCH 1 "18 May 1997" "Version 1.02"
.\"======================================================================
.SH NAME
bibsearch \- search BibTeX bibliography files
.\"======================================================================
.SH SYNOPSIS
.B bibsearch
.\"======================================================================
.SH DESCRIPTION
.B bibsearch
uses the
.BR mgquery (1)
database search engine to provide superfast
searching in a collection of \*(Bi\& bibliography
database files.  The database is generally updated
nightly, and on startup,
.B bibsearch
displays the date of the last update, plus some
statistics on the size of the collection.  It also
gives some helpful hints about commonly-used
commands.
.PP
The bibliography files make up the BibNet and TeX
User Group bibliography archive, and cover these
subject areas:
.RS
.TP \w'\(bu'u+1n
\(bu
computing and computer science,
.TP
\(bu
computer graphics and visualization,
.TP
\(bu
database research,
.TP
\(bu
electronic document representation,
.TP
\(bu
fonts,
.TP
\(bu
GNU Project of the Free Software Foundation,
.TP
\(bu
HTML and SGML,
.TP
\(bu
Internet,
.TP
\(bu
numerical algebra,
.TP
\(bu
Plan9,
.TP
\(bu
PostScript and PDF,
.TP
\(bu
statistics,
.TP
\(bu
supercomputing,
.TP
\(bu
symbolic algebra,
.TP
\(bu
\*(Te\& and Metafont,
.TP
\(bu
typography and typesetting,
.TP
\(bu
Unicode,
.TP
\(bu
UNIX, and
.TP
\(bu
the X Window System.
.RE
The collection includes about 80 journal-specific
bibliographies, of which about 20 provide
.I complete
coverage of their respective journals.
.PP
Each search result normally begins with a
separator line of dashes, followed by a World Wide
Web Universal Resource Locator (URL) address that
uniquely identifies the location of the
bibliography file.  Local users can see these
files directly in the UNIX network file system,
without having to launch
.BR ftp (1)
or a Web browser: just change the prefix
``ftp://ftp.math.utah.edu'' to ``/u/ftp'' to
create a local file name.  This may be handy if
you want to find related bibliography entries
serendipitously, without knowing exactly what they
contain.
.PP
By default,
.B bibsearch
uses query-ranked searching: you type several
words, and the search engine responds with a
sorted list of bibliography entries that contain
one or more of those words, in order of decreasing
number of matches.
.PP
To switch to Boolean searching, which allows
combination of words with Boolean AND (&), OR (|),
and NOT (!) operators, issue the
.B mgquery (1)
command
.RS
.nf
\&.set query boolean
.fi
.RE
.PP
Searching is based on words, where a word is a
consecutive string of letters, digits, hyphen
(minus), underscore, backslash, or apostrophe.
This permits searching for ordinary words, as well
as for ISSN and ISBN value, for programming
language variable names, for \*(Te\& control
sequences, and for names like ``O'Reilly''.  All
other characters are treated as word separators,
so to search for ``input/output'', you must search
for two words, ``input'' and ``output''.
Similarly, you could search for an e-mail address
``rms@prep.ai.mit.edu'' with the string ``rms prep
ai mit edu'', assuming the default query-ranked
search mode.
.PP
Searches always
.I ignore
letter case.
.PP
Partial word matches are not usually accepted: if you
search for ``tex'', neither ``text'' nor ``texture''
will match. However,
.BR mg (1)
will `stem' search words, removing common English
suffixes, so a search for ``mathematical'' will
first be reduced to ``mathemat'' and that will
match ``mathematical'', ``mathematics'', and
``mathematician''.  The current version of
.BR mgquery (1)
does not at present provide any way to suppress
this stemming.
.PP
You may find that using
.RS
.nf
\&.set mode hilite
.fi
.RE
makes it easier to spot the matched strings in the
output.  However, the highlighting requires
additional control characters that contaminate any
output directed to a file, so in such a case, you
should turn it off, by e.g.
.RS
.nf
\&.set mode text
\&.set pager "cat >>/tmp/foo.log"
.fi
.RE
.PP
For further information on searching with
.BR mgquery (1),
consult its manual pages, or
use the
.RS
.nf
\&.help
.fi
.RE
command.
.PP
Finally, to exit from
.BR bibsearch ,
use the
.BR mgquery (1)
.RS
.nf
\&.quit
.fi
.RE
command.
.PP
With each \*(Bi\& entry retrieved,
.B bibsearch
provides definitions of any \*(Bi\& strings used
in the entry.  This will likely result in many
duplicate string definitions, but they are easily
eliminated by a subsequent pass of the
bibliography data through
.BR bibsort (1).
Acknowledgement strings are not included in this
output, because they are often large, and because
few, if any, \*(Bi\& styles use them.  You can
find their definitions near the top of the
original \*(Bi\& file identified at the start of
each search result.
.\"======================================================================
.SH "SEE ALSO"
.BR bibcheck (1),
.BR bibclean (1),
.BR bibdup (1),
.BR bibextract (1),
.BR bibjoin (1),
.BR biblabel (1),
.BR biblex (1),
.BR biborder (1),
.BR bibparse (1),
.BR bibsort (1),
.BR bibtex (1),
.BR bibunlex (1),
.BR citesub (1),
.BR emacs (1),
.BR mg (1),
.BR mgquery (1).
.\"======================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe, Ph.D.
Center for Scientific Computing
Department of Mathematics
University of Utah
Salt Lake City, UT 84112
Tel: +1 801 581 5254
FAX: +1 801 581 4148
Email: <beebe@math.utah.edu>
WWW URL: http://www.math.utah.edu/~beebe
.fi
.\"==============================[The End]==============================
