#! /bin/sh
# This script is an interface to a large mgquery database of BibTeX
# bibliography files in the BibNet and TeX User Group (TUG)
# collections, the master archives for which reside at
# 	ftp://ftp.math.utah.edu/pub/bibnet
# 	ftp://ftp.math.utah.edu/pub/tex/bib/
#
# Usage:
#	bibsearch
#
# [13-May-1997]

collection=$1
if test "$collection" = "" ; then collection="bibfiles" ; fi

BIBTOP=/home/0057/src/bibdata/mgdata
MGQUERY=/usr/local/bin/mgquery

if test -f $MGQUERY
then
	true
else
# rsh access works poorly if a pager is selected, so instead, just
# tell the user to switch machines
#	rsh xserver.math.utah.edu \
#		"env MGDATA=$BIBTOP $MGQUERY $collection"
	echo "The mgquery search engine is not installed on this machine."
	echo "Please switch to a local Sun system, such as xserver.math.utah.edu"
	exit 1
fi

cat <<END-OF-COMMENTS
========================================================================
Welcome to the BibTeX bibliography database search facility
Version 1.02 [18-May-1997]

END-OF-COMMENTS

if test -f $BIBTOP/$collection/STATS.date
then
	awk '{printf("Last database update: %s\n",   $0)}' $BIBTOP/$collection/STATS.date
	awk '{printf("Bibliography entries: %10d\n", $1)}' $BIBTOP/$collection/STATS.entries
	awk '{printf("Bibliography lines:   %10d\n", $1)}' $BIBTOP/$collection/STATS.wc
	awk '{printf("Bibliography bytes:   %10d\n", $3)}' $BIBTOP/$collection/STATS.wc
fi

cat <<END-OF-COMMENTS

Commands to the mgquery search engine begin with an initial period.
Anything else is interpreted as a keyword search string.

Useful mgquery commands:
	.quit				# terminate
	.help 				# help

	.set pager less			# single screen output paging
	.set pager cat			# continuous output to screen
	.set pager "cat >>file"		# continuous output to file

	.set query boolean		# Boolean instead of ranked searches

	.set mode hilite		# highlighted match strings
	.set hilite_style bold		# bold highlighting
	.set hilite_style underline	# underlined highlighting

HINT:	Commands that you always issue can be put into your ~/.mgrc file
	which mgquery will read on startup.

Each output entry is prefixed by a World Wide Web Universal Resource
Locator (URL) address that uniquely identifies the location of the
bibliography file.  Local users can see these files directly: just
change the prefix ftp://ftp.math.utah.edu to /u/ftp to create a local
file name.

With mg version 1.2x, "words" to be searched for may contain letters,
digits, hyphen (minus), underscore, backslash, or apostrophe.

To search for a BibNet-style BibTeX citation label, such as
Knuth:1992:LP, use Boolean search:

	.set query boolean
	knuth & 1992 & lp

========================================================================
END-OF-COMMENTS

MGDATA=$BIBTOP
export MGDATA

if test -f $MGQUERY
then
	# [13-May-1997] cd to the data directory, in case there are
	# collection.* files in the user's current directory
	cd $MGDATA
	$MGQUERY $collection
else
# rsh access works poorly if a pager is selected, so instead, just
# tell the user to switch machines
#	rsh xserver.math.utah.edu \
#		"env MGDATA=$BIBTOP $MGQUERY $collection"
	echo "The mgquery search engine is not installed on this machine."
	echo "Please switch to a local Sun system, such as xserver.math.utah.edu"
fi
