# /home/0057/src/bibdata/mgdata/mg_get_bibtex.awk, Wed Feb 12 07:14:29 1997
# Edit by Nelson H. F. Beebe <beebe@chamberlin.math.utah.edu>
# ========================================================================
# Filter a BibTeX file for mg, removing comments, @preamble{}, and
# @string{} entries, and creating Ctl-B-separated records that each
# contain a single BibTeX entry, and in each of which, any BibTeX string
# abbreviations used for address, institution, journal, organization,
# publisher, school, and series are also defined by
# @String{name="value"} entries which are output as part of the record
# immediately before the BibTeX entry.
#
# Usage:
#	gawk -f mg_get.awk BibTeXfiles(s)
#
# NB: gawk is required because it supports the IGNORECASE variable.
#
# [12-Feb-1997]
# ========================================================================

BEGIN		{ initialize() }

/^%/		{ next }

/^[ \t]*$/	{ next }

/^@comment *{/	{ do_preamble(); next }

/^@preamble *{/	{ do_preamble(); next }

/^@string *{/	{ do_string(); next }

/^@/		{ do_entry(); next }

/^ *(address|institution|journal|organization|publisher|school|series) *= *[a-zA-Z]/ { do_abbrev(); next }

		{ save($0) }

END		{ print_and_forget_entry(); printf("%c",2) }

# ======================================================================

function brace_level(s, k,level,n)
{
    level = 0
    n = length(s)
    for (k = 1; k <= n; ++k)
    {
	if (substr(s,k,1) == "{")
	    level++
	else if (substr(s,k,1) == "}")
	    level--
    }
    return (level)
}

function do_abbrev( abbrev)
{
    save($0)
    abbrev = trim(substr($0,index($0,"=")+1))
    sub(/ *,$/,"",abbrev)
    if (abbrev in Define)
	Strings[++NStrings] = abbrev
}

function do_entry()
{
    print_and_forget_entry()
    EntryLineNumber = FNR
    save($0)
}

function do_preamble( level,x)
{
    level = brace_level($0)
    while ((level > 0) && (getline x > 0))
	level += brace_level(x)
}

function do_string( k1,k2,level,name,value,x)
{
    k1 = index($0,"{") + 1
    k2 = index($0,"=")
    name = trim(substr($0,k1,k2-k1))
    value = trim(substr($0,k2+1))
    level = brace_level($0)
    while ((level > 0) && (getline x > 0))
    {
	x = trim(x)
	level += brace_level(x)
	value = value " " x
    }
    gsub(/  +/," ",value)
    Define[name] = value
}

function initialize()
{
    IGNORECASE = 1

    EntryLineNumber = 0
    NStrings = 0
    NLines = 0
}

function print_and_forget_entry( href,k)
{
    if (NLines > 0)
    {
	href = FILENAME
	sub(/^\/u\/ftp/, "ftp://ftp.math.utah.edu", href)
	printf("%cURL=%s Line=%d\n\n", 2, href, EntryLineNumber)
    }

    for (k = 1; k <= NStrings; ++k)
	printf("@String{%-23s = %s\n\n", Strings[k], Define[Strings[k]])
    NStrings = 0

    for (k = 1; k <= NLines; ++k)
	print Lines[k]
    NLines = 0
}

function save(s)
{
    Lines[++NLines] = s
}

function trim(s)
{
    sub(/^[ \t]+/,"",s)
    sub(/[ \t]+$/,"",s)
    return (s)
}
